@@ -154,11 +154,11 @@ void AbstractEglBackend::initWayland()
         QHash<uint32_t, QList<uint64_t>> set;
         for (auto it = formats.constBegin(); it != formats.constEnd(); it++) {
             const auto info = FormatInfo::get(it.key());
-            if (!info || (bpc && bpc != info->bitsPerColor)) {
+            if (bpc && (!info || bpc != info->bitsPerColor)) {
                 continue;
             }
 
-            const bool externalOnlySupported = withExternalOnlyYUV && info->yuvConversion();
+            const bool externalOnlySupported = withExternalOnlyYUV && info && info->yuvConversion();
             QList<uint64_t> modifiers = externalOnlySupported ? it->allModifiers : it->nonExternalOnlyModifiers;
 
             if (externalOnlySupported && !modifiers.isEmpty()) {
