@@ -21,6 +21,7 @@ class OutputScreenCastSource : public ScreenCastSource
 
 public:
     explicit OutputScreenCastSource(Output *output, QObject *parent = nullptr);
+    ~OutputScreenCastSource() override;
 
     uint refreshRate() const override;
     bool hasAlphaChannel() const override;
@@ -31,8 +32,14 @@ public:
     void render(spa_data *spa, spa_video_format format) override;
     std::chrono::nanoseconds clock() const override;
 
+    void resume() override;
+    void pause() override;
+
 private:
+    void report(const QRegion &damage);
+
     QPointer<Output> m_output;
+    bool m_active = false;
 };
 
 } // namespace KWin
