@@ -91,22 +91,22 @@ void DecorationRenderer::renderToPainter(QPainter *painter, const QRect &rect)
 DecorationItem::DecorationItem(KDecoration2::Decoration *decoration, Window *window, Scene *scene, Item *parent)
     : Item(scene, parent)
     , m_window(window)
+    , m_decoration(decoration)
 {
     m_renderer = Compositor::self()->scene()->createDecorationRenderer(window->decoratedClient());
 
-    connect(window, &Window::frameGeometryChanged,
-            this, &DecorationItem::handleFrameGeometryChanged);
     connect(window, &Window::outputChanged,
             this, &DecorationItem::handleOutputChanged);
 
+    connect(decoration->client(), &KDecoration2::DecoratedClient::sizeChanged,
+            this, &DecorationItem::handleDecorationGeometryChanged);
     connect(decoration, &KDecoration2::Decoration::bordersChanged,
-            this, &DecorationItem::discardQuads);
+            this, &DecorationItem::handleDecorationGeometryChanged);
 
     connect(renderer(), &DecorationRenderer::damaged,
             this, qOverload<const QRegion &>(&Item::scheduleRepaint));
 
-    // this toSize is to match that DecoratedWindow also rounds
-    setSize(window->size().toSize());
+    setSize(decoration->size());
     handleOutputChanged();
 }
 
@@ -124,7 +124,17 @@ QRegion DecorationItem::opaque() const
     }
     QRectF left, top, right, bottom;
     m_window->layoutDecorationRects(left, top, right, bottom);
-    return QRegion(left.toRect()).united(top.toRect()).united(right.toRect()).united(bottom.toRect());
+
+    // We have to map to integers which has rounding issues
+    // it's safer for a region to be considered transparent than opaque
+    // so always align inwards
+    const QMargins roundingPad = QMargins(1, 1, 1, 1);
+    QRegion roundedLeft = left.toAlignedRect().marginsRemoved(roundingPad);
+    QRegion roundedTop = top.toAlignedRect().marginsRemoved(roundingPad);
+    QRegion roundedRight = right.toAlignedRect().marginsRemoved(roundingPad);
+    QRegion roundedBottom = bottom.toAlignedRect().marginsRemoved(roundingPad);
+
+    return roundedLeft | roundedTop | roundedRight | roundedBottom;
 }
 
 void DecorationItem::preprocess()
@@ -159,9 +169,10 @@ void DecorationItem::handleOutputScaleChanged()
     }
 }
 
-void DecorationItem::handleFrameGeometryChanged()
+void DecorationItem::handleDecorationGeometryChanged()
 {
-    setSize(m_window->size().toSize());
+    setSize(m_decoration->size());
+    discardQuads();
 }
 
 DecorationRenderer *DecorationItem::renderer() const
